.. _contributing:

Contributing to ytree
=====================

ytree is a community project and it will be better with your
contribution.

Contributions are welcome in the form of code, documentation, or
just about anything.  If you're interested in getting involved,
please do!

ytree is developed using the same conventions as yt.  The `yt
Developer Guide <http://yt-project.org/docs/dev/developing/index.html>`_
is a good reference for code style, communication with other developers,
working with git, and issuing pull requests.  For information specific
to ytree, such as testing and adding support for new file formats, see
the `ytree Developer Guide
<http://ytree.readthedocs.io/en/latest/Developing.html>`__.

If you'd like to know more, contact Britton Smith (brittonsmith@gmail.com)
or come by the #ytree channel on the `yt project Slack
<https://yt-project.org/slack.html>`__.

You can also find help on the `yt developers list
<http://lists.spacepope.org/listinfo.cgi/yt-users-spacepope.org>`_.
